@@ -16,7 +16,7 @@ from datetime import datetime
 import subprocess
 
 
-version = '1.2.0'
+version = '1.2.1'
 __version__ = version
 program = 'chaptermarkers'
 description = 'Chapter markers creates markers in MP4 files from friendly time marks'
@@ -94,7 +94,8 @@ def main(args=None):
 
         with open(TEMPFILE, "w") as myfile:
             myfile.write(text)
-
+    if DEBUG:
+        print("Adding chapter markers to {filename} writing changes to {output}".format(filename=FILENAME,output=OUTPUT))
     writeMetada(TEMPFILE, FILENAME, OUTPUT)
 
     return 0
@@ -208,7 +209,7 @@ def setup(configuration):
 
 
 def writeMetada(ffmetadata, video, output):
-    TEMPLATE = "{FFMPEG} -hide_banner -i {INPUT} -i {FFMETADATAFILE} -map_metadata 1 -codec copy {OUTPUT} -y".\
+    TEMPLATE = "{FFMPEG} -hide_banner -i '{INPUT}' -i {FFMETADATAFILE} -map_metadata 1 -codec copy '{OUTPUT}' -y".\
         format(FFMPEG=FFMPEGCMD, FFMETADATAFILE=ffmetadata, INPUT=video, OUTPUT=output)
     subprocess.run(TEMPLATE, shell=True)
     if DEBUG:
